<?php

namespace App\Command;

use Doctrine\DBAL\Connection;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

class PopulateDBEmojiAvailableCommand extends Command
{

    protected static $defaultName = 'app:popDBEmojiAvai';

    private Connection $connection;

    public function __construct(Connection $connection)
    {
        parent::__construct();
        $this->connection = $connection;
    }

    protected function configure()
    {
        $this
            ->setDescription('Populate the database.');
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        try {

            // On supprime la table si elle existe déjà
            $this->connection->executeStatement('DROP TABLE IF EXISTS stock_emoji');

            // On crée la table
            $this->connection->executeStatement('
                CREATE TABLE stock_emoji (
                    id INT PRIMARY KEY,
                    code VARCHAR(255) NOT NULL,
                    name VARCHAR(255) NOT NULL
                )
            ');

            
            // On peuple la table
            $this->connection->executeStatement("INSERT INTO stock_emoji (id, code, name) VALUES 
                (1,'🤖','Rodolph'),
                (2,'😺','Bobette'),
                (3,'🧠','Diana'),
                (4,'👻','Ian'),
                (5,'🧟','Alice'),
                (6,'🐶','Eric'),
                (7,'👽','Hannah'),
                (8,'🧛','Fiona'),
                (9,'🎃','George'),
                (10,'🐸','John'),
                (11,'⚡','Charlie'),
                (12,'💀','Benoit'),
                (13,'🔥','Sophie'),
                (14,'🧙','Bob'),
                (15,'🌪️','Ethan'),
                (16,'😎','Luna'),
                (17,'😁','Maxence'),
                (18,'🌟','Jasper'),
                (19,'😈','Nora')
            ");

            $output->writeln('Base de données peuplée.');
        } catch (\Exception $e) {
            $output->writeln('<error>Erreur : ' . $e->getMessage() . '</error>');
            return Command::FAILURE;
        }

        return Command::SUCCESS;
    }
}
